@@ -25,11 +25,15 @@ from types import StringTypes
 from ConfigParser import DuplicateSectionError, NoSectionError, NoOptionError
 
 from zenmapCore.Paths import Path
-from zenmapCore.ScanProfileConf import scan_profile_file
 from zenmapCore.UmitLogging import log
 from zenmapCore.UmitConfigParser import UmitConfigParser
-from zenmapCore.I18N import _
+import zenmapCore.I18N
 
+# This is the global configuration parser object that represents the contents of
+# zenmap.conf. It should be initialized once by the application. Most
+# interaction with the global parser is done by other classes in this file, like
+# SearchConfig, that wrap specific configuration sections.
+config_parser = UmitConfigParser()
 
 # Check if running on Maemo
 MAEMO = False
@@ -42,70 +46,29 @@ except ImportError:
 def is_maemo():
     return MAEMO
 
-class UmitConf(object):
-    def __init__(self):
-        self.parser = Path.config_parser
-
-    def save_changes(self):
-        self.parser.save_changes()
-
-    def get_colored_diff(self):
-        try:
-            cd = self.parser.get('diff', 'colored_diff')
-            if cd == "False" or \
-                cd == "false" or \
-                cd == "0" or \
-                cd == "" or \
-                cd == False:
-                return False
-            return True
-        except:
-            return True
-
-    def set_colored_diff(self, enable):
-        if not self.parser.has_section('diff'):
-            self.parser.add_section('diff')
-
-        self.parser.set('diff', 'colored_diff', str(enable))
-
-    def get_diff_mode(self):
-        try: return self.parser.get('diff', 'diff_mode')
-        except: return "compare"
-
-    def set_diff_mode(self, diff_mode):
-        if not self.parser.has_section('diff'):
-            self.parser.add_section('diff')
-        
-        self.parser.set('diff', 'diff_mode', diff_mode)
-
-    colored_diff = property(get_colored_diff, set_colored_diff)
-    diff_mode = property(get_diff_mode, set_diff_mode)
-
-
 class SearchConfig(UmitConfigParser, object):
-    def __init__(self):
-        self.parser = Path.config_parser
+    section_name = "search"
 
-        self.section_name = "search"
-        if not self.parser.has_section(self.section_name):
+    def __init__(self):
+        if not config_parser.has_section(self.section_name):
             self.create_section()
 
     def save_changes(self):
-        self.parser.save_changes()
+        config_parser.save_changes()
 
     def create_section(self):
-        self.parser.add_section(self.section_name)
+        config_parser.add_section(self.section_name)
         self.directory = ""
-        self.file_extension = "usr"
+        self.file_extension = "xml"
         self.save_time = "60;days"
         self.store_results = True
         self.search_db = True
 
     def _get_it(self, p_name, default):
-        return self.parser.get(self.section_name, p_name, default)
+        return config_parser.get(self.section_name, p_name, default)
 
     def _set_it(self, p_name, value):
-        self.parser.set(self.section_name, p_name, value)
+        config_parser.set(self.section_name, p_name, value)
         
     def boolean_sanity(self, attr):
         if attr == True or \
@@ -124,7 +87,7 @@ class SearchConfig(UmitConfigParser, object):
         self._set_it("directory", directory)
 
     def get_file_extension(self):
-        return self._get_it("file_extension", "usr").split(";")
+        return self._get_it("file_extension", "xml").split(";")
 
     def set_file_extension(self, file_extension):
         if type(file_extension) == type([]):
@@ -184,11 +147,11 @@ class Profile(UmitConfigParser, object):
     them found in a config file such as scan_profiles.usp. The methods therefore
     all take an argument that is the name of the profile to work on."""
 
-    def __init__(self, user_profile=None, *args):
+    def __init__(self, user_profile = None, *args):
         UmitConfigParser.__init__(self, *args)
 
         if not user_profile:
-            user_profile = scan_profile_file
+            user_profile = Path.scan_profile
 
         fconf = open(user_profile, 'r')
         self.readfp(fconf, user_profile)
@@ -220,31 +183,10 @@ class Profile(UmitConfigParser, object):
         except DuplicateSectionError:
             return None
 
-        # Set each of the attributes ("command", "hint", "options",
-        # "description", "annotation") in the ConfigParser.
+        # Set each of the attributes ("command", "description") in the
+        # ConfigParser.
         for attr in attributes:
-            if attr == "options":
-                # We handle the "options" attribute specially because it is a
-                # dict, not a plain string.
-                options = attributes["options"]
-                assert type(options) == dict
-
-                # The "options" attribute looks like, for example,
-                #   options = Ports to scan,Verbose,Aggressive
-                self._set_it(profile_name, "options", ",".join(options.keys()))
-
-                # Some of the options take an argument, which is also stored in
-                # the scan profiles file. Arguments are the values associated
-                # with keys in the dict, if not None. For example,
-                #   ports to scan = 1-1024
-                # might be stored in the file, meaning "-p1-1024". (Notice that
-                # case is not significant.)
-                for opt in options:
-                    if options[opt]:
-                        self._set_it(profile_name, opt, options[opt])
-            else:
-                # The other attributes are just strings so simply set them.
-                self._set_it(profile_name, attr, attributes[attr])
+            self._set_it(profile_name, attr, attributes[attr])
 
         self.save_changes()
 
@@ -260,89 +202,44 @@ class Profile(UmitConfigParser, object):
 
 class CommandProfile (Profile, object):
     """This class is a wrapper around Profile that provides accessors for the
-    attributes of a profile: command, hint, options, description, and
-    annotation."""
-    def __init__(self, user_profile=''):
-        if not user_profile:
-            user_profile = scan_profile_file
-        
+    attributes of a profile: command and description"""
+    def __init__(self, user_profile = None):
         Profile.__init__(self, user_profile)
         
     def get_command(self, profile):
-        return self._get_it(profile, 'command')
-
-    def get_hint(self, profile):
-        return self._get_it(profile, 'hint')
+        command_string = self._get_it(profile, 'command')
+        # Old versions of Zenmap used to append "%s" to commands and use that to
+        # substitute the target. Ignore it if present.
+        if command_string.endswith("%s"):
+            command_string = command_string[:-len("%s")]
+        return command_string
 
     def get_description(self, profile):
         return self._get_it(profile, 'description')
     
-    def get_annotation(self, profile):
-        return self._get_it(profile, 'annotation')
-
-    def get_options(self, profile):
-        """Return a dict of options and their corresponding arguments. Use None
-        as the value for options that don't have an argument."""
-        dic = {}
-        options_str = self._get_it(profile, 'options')
-        # If we get back an empty string, there are no options.
-        if options_str.strip() == '':
-            return dic
-        for opt in options_str.split(','):
-            opt = opt.strip()
-            # Arguments for options are stored in the same way as the list of
-            # options itself, as name-value pairs, with the option as the name
-            # and the argument as the value. So for example you might have
-            #   options = Ports to scan,Verbose,Aggressive
-            #   ports to scan = 1-1024
-            # and case is not significant in the option name.
-            try:
-                dic[unicode(opt)] = self._get_it(profile, opt)
-            except NoOptionError:
-                dic[unicode(opt)] = None
-        return dic
-
     def set_command(self, profile, command=''):
         self._set_it(profile, 'command', command)
 
-    def set_hint(self, profile, hint=''):
-        self._set_it(profile, 'hint', hint)
-    
     def set_description(self, profile, description=''):
         self._set_it(profile, 'description', description)
     
-    def set_annotation (self, profile, annotation=''):
-        self._set_it(profile, 'annotation', annotation)
-    
-    def set_options(self, profile, options={}):
-        for opt in options:
-            if options[opt]:
-                self._set_it(profile, opt, options[opt])
-        self._set_it(profile, 'options', ",".join(options.keys()))
-
     def get_profile(self, profile_name):
         return {'profile':profile_name, \
                 'command':self.get_command(profile_name), \
-                'hint':self.get_hint(profile_name), \
-                'description':self.get_description(profile_name), \
-                'annotation':self.get_annotation(profile_name),\
-                'options':self.get_options(profile_name)}
+                'description':self.get_description(profile_name)}
 
 
 class NmapOutputHighlight(object):
     setts = ["bold", "italic", "underline", "text", "highlight", "regex"]
     
-    def __init__(self):
-        self.parser = Path.config_parser
-
     def save_changes(self):
-        self.parser.save_changes()
+        config_parser.save_changes()
 
     def __get_it(self, p_name):
         property_name = "%s_highlight" % p_name
 
         try:
-            return self.sanity_settings([self.parser.get(property_name,
+            return self.sanity_settings([config_parser.get(property_name,
                                                          prop,
                                                          True) \
                                          for prop in self.setts])
@@ -364,7 +261,7 @@ class NmapOutputHighlight(object):
         property_name = "%s_highlight" % property_name
         settings = self.sanity_settings(list(settings))
 
-        [self.parser.set(property_name, self.setts[pos], settings[pos]) \
+        [config_parser.set(property_name, self.setts[pos], settings[pos]) \
          for pos in xrange(len(settings))]
 
     def sanity_settings(self, settings):
@@ -382,10 +279,10 @@ class NmapOutputHighlight(object):
         settings[2] = self.boolean_sanity(settings[2])
 
         tuple_regex = "[\(\[]\s?(\d+)\s?,\s?(\d+)\s?,\s?(\d+)\s?[\)\]]"
-        if type(settings[3]) == type(""):
+        if isinstance(settings[3], basestring):
             settings[3] = [int(t) for t in re.findall(tuple_regex, settings[3])[0]]
 
-        if type(settings[4]) == type(""):
+        if isinstance(settings[4], basestring):
             settings[4]= [int(h) for h in re.findall(tuple_regex, settings[4])[0]]
 
         return settings
@@ -446,9 +343,9 @@ class NmapOutputHighlight(object):
     def get_enable(self):
         enable = True
         try:
-            enable = self.parser.get("output_highlight", "enable_highlight")
+            enable = config_parser.get("output_highlight", "enable_highlight")
         except NoSectionError:
-            self.parser.set("output_highlight", "enable_highlight", str(True))
+            config_parser.set("output_highlight", "enable_highlight", str(True))
         
         if enable == "False" or enable == "0" or enable == "":
             return False
@@ -456,9 +353,9 @@ class NmapOutputHighlight(object):
 
     def set_enable(self, enable):
         if enable == False or enable == "0" or enable == None or enable == "":
-            self.parser.set("output_highlight", "enable_highlight", str(False))
+            config_parser.set("output_highlight", "enable_highlight", str(False))
         else:
-            self.parser.set("output_highlight", "enable_highlight", str(True))
+            config_parser.set("output_highlight", "enable_highlight", str(True))
 
     date = property(get_date, set_date)
     hostname = property(get_hostname, set_hostname)
@@ -483,7 +380,7 @@ class NmapOutputHighlight(object):
                             "underline":str(True),
                             "text":[0, 111, 65535],
                             "highlight":[65535, 65535, 65535],
-                            "regex":"(\w{2,}://)*\w{2,}\.\w{2,}(\.\w{2,})*(/[\w{2,}]*)*"},
+                            "regex":"(\w{2,}://)*[\w-]{2,}\.[\w-]{2,}(\.[\w-]{2,})*(/[[\w-]{2,}]*)*"},
                           "ip":{"bold":str(True),
                             "italic":str(False),
                             "underline":str(False),
@@ -521,87 +418,38 @@ class NmapOutputHighlight(object):
                             "highlight":[65535, 65535, 65535],
                             "regex":"^(\w{2,}[\s]{,3}){,4}:"}}
 
-class DiffColors(object):
-    def __init__(self):
-        self.parser = Path.config_parser
-        self.section_name = "diff_colors"
-
-    def save_changes(self):
-        self.parser.save_changes()
-
-    def __get_it(self, p_name):
-        return self.sanity_settings(self.parser.get(self.section_name, p_name))
-
-    def __set_it(self, property_name, settings):
-        settings = self.sanity_settings(settings)
-        self.parser.set(self.section_name, property_name, settings)
-
-    def sanity_settings(self, settings):
-        log.debug(">>> Sanitize %s" % str(settings))
-        
-        tuple_regex = "[\(\[]\s?(\d+)\s?,\s?(\d+)\s?,\s?(\d+)\s?[\)\]]"
-        if type(settings) == type(""):
-            settings = [int(t) for t in re.findall(tuple_regex, settings)[0]]
-
-        return settings
-
-    def get_unchanged(self):
-        return self.__get_it("unchanged")
-
-    def set_unchanged(self, settings):
-        self.__set_it("unchanged", settings)
-
-    def get_added(self):
-        return self.__get_it("added")
-
-    def set_added(self, settings):
-        self.__set_it("added", settings)
-
-    def get_modified(self):
-        return self.__get_it("modified")
-
-    def set_modified(self, settings):
-        self.__set_it("modified", settings)
-
-    def get_not_present(self):
-        return self.__get_it("not_present")
-
-    def set_not_present(self, settings):
-        self.__set_it("not_present", settings)
-
-    unchanged = property(get_unchanged, set_unchanged)
-    added = property(get_added, set_added)
-    modified = property(get_modified, set_modified)
-    not_present = property(get_not_present, set_not_present)
-
-
 # Retrieve details from zenmap.conf regarding paths subsection
 # (e.g. nmap_command_path) - jurand
 class PathsConfig(object):
-    def __init__(self):
-        self.parser = Path.config_parser
-        self.section_name = "paths"
+    section_name = "paths"
 
     # This accounts for missing entries conf file.
     # Defaults to "nmap" if these errors occur.
     # NoOptionError, NoSectionError
-    def __get_it(self, p_name):
-	try:
-        	return self.parser.get(self.section_name, p_name)
-	except (NoOptionError,NoSectionError):
-		log.debug(">>> nmap command path not configured. Using default 'nmap'.")
-		return "nmap"
+    def __get_it(self, p_name, default):
+        try:
+            return config_parser.get(self.section_name, p_name)
+        except (NoOptionError,NoSectionError):
+            log.debug(">>> Using default \"%s\" for \"%s\"." % (default, p_name))
+            return default
 
     def __set_it(self, property_name, settings):
-        self.parser.set(self.section_name, property_name, settings)
+        config_parser.set(self.section_name, property_name, settings)
 
     def get_nmap_command_path(self):
-        return self.__get_it("nmap_command_path")
+        return self.__get_it("nmap_command_path", "nmap")
 
     def set_nmap_command_path(self, settings):
         self.__set_it("nmap_command_path", settings)
 
+    def get_ndiff_command_path(self):
+        return self.__get_it("ndiff_command_path", "ndiff")
+
+    def set_ndiff_command_path(self, settings):
+        self.__set_it("ndiff_command_path", settings)
+
     nmap_command_path = property(get_nmap_command_path, set_nmap_command_path)
+    ndiff_command_path = property(get_ndiff_command_path, set_ndiff_command_path)
 
 # Exceptions
 class ProfileNotFound:
@@ -615,7 +463,3 @@ class ProfileCouldNotBeSaved:
         self.profile = profile
     def __str__ (self):
         return "Profile named '"+self.profile+"' could not be saved!"
-
-
-if __name__ == "__main__":
-    pass
