@@ -31,7 +31,20 @@ import ConfigParser
 # segmentation fault. See http://live.gnome.org/PyGTK/WhatsNew210.
 import warnings
 warnings.filterwarnings("error", module = "gtk")
-import gtk
+try:
+    import gtk
+except Exception:
+    # On Mac OS X 10.5, X11 is supposed to be automatically launched on demand.
+    # It works by setting the DISPLAY environment variable to something like
+    # "/tmp/launch-XXXXXX/:0" and intercepting traffic on that socket; see
+    # http://homepage.mac.com/sao1/X11/#four. However this breaks in a strange
+    # way if DISPLAY is set in one of the shell startup files like .profile.
+    # Those files only have an effect on the shell, not the graphical
+    # environment, so X11 starts up as expected, but in doing so it reads the
+    # startup scripts, and for some reason the first connection (the one that
+    # caused the launch) is rejected. But somehow subsequent connections work
+    # fine! So if the import fails, try one more time.
+    import gtk
 warnings.resetwarnings()
 
 from zenmapGUI.higwidgets.higdialogs import HIGAlertDialog
@@ -43,8 +56,7 @@ from zenmapCore.UmitLogging import log
 from zenmapCore.UmitOptionParser import option_parser
 from zenmapCore.Name import APP_DISPLAY_NAME, NMAP_DISPLAY_NAME
 from zenmapCore.UmitConf import SearchConfig
-from zenmapCore.I18N import _
-from zenmapCore.UmitDB import UmitDB
+import zenmapCore.I18N
 from zenmapCore.Paths import Path
 from zenmapCore.Name import APP_DISPLAY_NAME
 
@@ -60,8 +72,13 @@ def _destroy_callback(window):
     open_windows.remove(window)
     if len(open_windows) == 0:
         gtk.main_quit()
-    # Cleaning up data base
-    UmitDB().cleanup(SearchConfig().converted_save_time)
+    try:
+        from zenmapCore.UmitDB import UmitDB
+    except ImportError, e:
+        log.debug(">>> Not cleaning up database: %s." % str(e))
+    else:
+        # Cleaning up data base
+        UmitDB().cleanup(SearchConfig().converted_save_time)
 
 def new_window():
     w = ScanWindow()
@@ -69,7 +86,7 @@ def new_window():
     if is_maemo():
         import hildon
         hildon_app = hildon.Program()
-        hildon_app.add_window(window)
+        hildon_app.add_window(w)
     open_windows.append(w)
     return w
 
@@ -113,7 +130,7 @@ The specific error was\n\
 \n\
 %s needs to create this directory to store information such as the list of \
 scan profiles. Check for access to the directory and try again.\
-""") % (Path.user_config_dir, Path.config_dir, str(e), APP_DISPLAY_NAME))
+""") % (repr(Path.user_config_dir), repr(Path.config_dir), repr(str(e)), APP_DISPLAY_NAME))
         error_dialog.run()
         error_dialog.destroy()
         sys.exit(1)
@@ -162,12 +179,12 @@ until it is repaired.\
 
     if nmap:
         # Start running a scan if given by the -n option.
-        page = window.get_empty_page()
+        page = window.get_empty_interface()
         page.command_toolbar.command = " ".join(nmap)
         page.start_scan_cb()
     elif target or profile:
         # Set up target and profile according to the -t and -p options.
-        page = window.get_empty_page()
+        page = window.get_empty_interface()
         if target:
             page.toolbar.selected_target = target
         if profile:
@@ -188,7 +205,7 @@ until it is repaired.\
 class NonRootWarning (HIGAlertDialog):
     def __init__(self):
         warning_text = _('''You are trying to run %s with a non-root user!\n
-Some %s options need root privileges to work.''' % (APP_DISPLAY_NAME, NMAP_DISPLAY_NAME))
+Some %s options need root privileges to work.''') % (APP_DISPLAY_NAME, NMAP_DISPLAY_NAME)
         
-        HIGAlertDialog.__init__(self, message_format=_('Non root user'),
+        HIGAlertDialog.__init__(self, message_format=_('Non-root user'),
                                 secondary_text=warning_text)
