@@ -23,7 +23,7 @@ import gtk
 
 from zenmapGUI.SearchGUI import SearchGUI
 
-from zenmapCore.I18N import _
+import zenmapCore.I18N
 from zenmapCore.UmitConf import is_maemo
 
 from zenmapGUI.higwidgets.higboxes import HIGVBox
@@ -70,7 +70,7 @@ class SearchWindow(BaseSearchWindow, object):
         self.bottom_label = gtk.Label()
         self.btn_box = gtk.HButtonBox()
         self.btn_open = HIGButton(stock=gtk.STOCK_OPEN)
-        self.btn_append = HIGButton("Append", gtk.STOCK_ADD)
+        self.btn_append = HIGButton(_("Append"), gtk.STOCK_ADD)
         self.btn_close = HIGButton(stock=gtk.STOCK_CLOSE)
         
         self.search_gui = SearchGUI(self)
